@@ -17,7 +17,7 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Classes and functions related to data identification and querying."""
 
+from .anc_vars import dataset_walker, replace_anc  # noqa
+from .data_dict import DatasetDict, get_key  # noqa
 from .dataid import DataID, DataQuery, ModifierTuple, create_filtered_query  # noqa
-from .data_dict import get_key, DatasetDict  # noqa
 from .metadata import combine_metadata  # noqa
-from .anc_vars import dataset_walker, replace_anc  # noqa
\ No newline at end of file
