@@ -45,7 +45,14 @@ def get_keys_from_config(common_id_keys, config):
 
 
 class ValueList(IntEnum):
-    """A static value list."""
+    """A static value list.
+
+    This class is meant to be used for dynamically created Enums. Due to this
+    it should not be used as a normal Enum class or there may be some
+    unexpected behavior. For example, this class contains custom pickling and
+    unpickling handling that may break in subclasses.
+
+    """
 
     @classmethod
     def convert(cls, value):
@@ -55,6 +62,21 @@ class ValueList(IntEnum):
         except KeyError:
             raise ValueError('{} invalid value for {}'.format(value, cls))
 
+    @classmethod
+    def _unpickle(cls, enum_name, enum_members, enum_member):
+        """Create dynamic class that was previously pickled.
+
+        See :meth:`__reduce_ex__` for implementation details.
+
+        """
+        enum_cls = cls(enum_name, enum_members)
+        return enum_cls[enum_member]
+
+    def __reduce_ex__(self, proto):
+        """Reduce the object for pickling."""
+        return (ValueList._unpickle,
+                (self.__class__.__name__, list(self.__class__.__members__.keys()), self.name))
+
     def __eq__(self, other):
         """Check equality."""
         return self.name == other
