@@ -21,10 +21,10 @@ import logging
 import warnings
 
 import numpy as np
-import xarray as xr
+
 from satpy.aux_download import DataDownloadMixin, retrieve
 from satpy.modifiers import ModifierBase
-from satpy.modifiers._angles import get_angles
+from satpy.modifiers.angles import get_angles
 
 LOG = logging.getLogger(__name__)
 
@@ -73,7 +73,7 @@ class ReflectanceCorrector(ModifierBase, DataDownloadMixin):
     def __call__(self, datasets, optional_datasets, **info):
         """Create modified DataArray object by applying the crefl algorithm."""
         from satpy.modifiers._crefl_utils import get_coefficients
-        refl_data, *angles = self._get_data_and_angles(datasets, optional_datasets)
+        refl_data, angles = self._extract_angle_data_arrays(datasets, optional_datasets)
         coefficients = get_coefficients(refl_data.attrs["sensor"],
                                         refl_data.attrs["wavelength"],
                                         refl_data.attrs["resolution"])
@@ -124,6 +124,7 @@ class ReflectanceCorrector(ModifierBase, DataDownloadMixin):
     @staticmethod
     def _read_var_from_hdf4_file_netcdf4(local_filename, var_name):
         from netCDF4 import Dataset as NCDataset
+
         # HDF4 file, NetCDF library needs to be compiled with HDF4 support
         nc = NCDataset(local_filename, "r")
         # average elevation is stored as a 16-bit signed integer but with
@@ -147,11 +148,6 @@ class ReflectanceCorrector(ModifierBase, DataDownloadMixin):
         except HDF4Error:
             return np.iinfo(dtype).min
 
-    def _get_data_and_angles(self, datasets, optional_datasets):
-        vis, angles = self._extract_angle_data_arrays(datasets, optional_datasets)
-        angles = [xr.DataArray(dask_arr, dims=('y', 'x')) for dask_arr in angles]
-        return [vis] + angles
-
     def _extract_angle_data_arrays(self, datasets, optional_datasets):
         all_datasets = datasets + optional_datasets
         if len(all_datasets) == 1:
@@ -160,8 +156,7 @@ class ReflectanceCorrector(ModifierBase, DataDownloadMixin):
         if len(all_datasets) == 5:
             vis, *angles = self.match_data_arrays(
                 datasets + optional_datasets)
-            # get the dask array underneath
-            return vis, [data_arr.data for data_arr in angles]
+            return vis, angles
         raise ValueError("Not sure how to handle provided dependencies. "
                          "Either all 4 angles must be provided or none of "
                          "of them.")
