@@ -420,11 +420,16 @@ def run_crefl(refl, coeffs,
     if use_abi:
         LOG.debug("Using ABI CREFL algorithm")
         corr_refl = da.map_blocks(_run_crefl_abi, refl.data, mus.data, muv.data, phi.data,
-                                  solar_zenith, sensor_zenith, height, *coeffs, percent=percent)
+                                  solar_zenith.data, sensor_zenith.data, height, *coeffs,
+                                  meta=np.ndarray((), dtype=refl.dtype),
+                                  chunks=refl.chunks, dtype=refl.dtype,
+                                  percent=percent)
     else:
         LOG.debug("Using original VIIRS CREFL algorithm")
         corr_refl = da.map_blocks(_run_crefl, refl.data, mus.data, muv.data, phi.data,
-                                  height, *coeffs, chunks=refl.chunks, dtype=refl.dtype,
+                                  height, *coeffs,
+                                  meta=np.ndarray((), dtype=refl.dtype),
+                                  chunks=refl.chunks, dtype=refl.dtype,
                                   percent=percent)
     return xr.DataArray(corr_refl, dims=refl.dims, coords=refl.coords, attrs=refl.attrs)
 
