@@ -30,10 +30,15 @@ from datetime import datetime
 import numpy as np
 import xarray as xr
 
-from satpy.readers._geos_area import get_area_extent, get_area_definition
-from satpy.readers.hrit_base import (HRITFileHandler, ancillary_text,
-                                     annotation_header, base_hdr_map,
-                                     image_data_function, time_cds_short)
+from satpy.readers._geos_area import get_area_definition, get_area_extent
+from satpy.readers.hrit_base import (
+    HRITFileHandler,
+    ancillary_text,
+    annotation_header,
+    base_hdr_map,
+    image_data_function,
+    time_cds_short,
+)
 
 logger = logging.getLogger('hrit_electrol')
 
@@ -156,7 +161,6 @@ class HRITGOMSPrologueFileHandler(HRITFileHandler):
 
     def process_prologue(self):
         """Reprocess prologue to correct types."""
-        pass
 
 
 radiometric_processing = np.dtype([("TagType", "<u4"),
