@@ -27,23 +27,24 @@ References:
 import logging
 from datetime import datetime, timedelta
 
+import dask.array as da
 import numpy as np
 import xarray as xr
-import dask.array as da
-
 from pyresample import geometry
 
-from satpy.readers.eum_base import (time_cds_short, recarray2dict)
-from satpy.readers.hrit_base import (HRITFileHandler, ancillary_text,
-                                     annotation_header, base_hdr_map,
-                                     image_data_function)
+from satpy.readers.eum_base import recarray2dict, time_cds_short
+from satpy.readers.hrit_base import (
+    HRITFileHandler,
+    ancillary_text,
+    annotation_header,
+    base_hdr_map,
+    image_data_function,
+)
 
 
 class CalibrationError(Exception):
     """Dummy error-class."""
 
-    pass
-
 
 logger = logging.getLogger('hrit_goes')
 
