@@ -185,20 +185,19 @@ The main differences are:
 
 """
 
+import logging
+import re
 from abc import abstractmethod
 from collections import namedtuple
 from datetime import datetime, timedelta
-import logging
-import re
 
 import numpy as np
+import pyresample.geometry
 import xarray as xr
 
-import pyresample.geometry
 from satpy import CHUNK_SIZE
 from satpy.readers.file_handlers import BaseFileHandler
-from satpy.readers.goes_imager_hrit import (SPACECRAFTS, EQUATOR_RADIUS, POLE_RADIUS,
-                                            ALTITUDE)
+from satpy.readers.goes_imager_hrit import ALTITUDE, EQUATOR_RADIUS, POLE_RADIUS, SPACECRAFTS
 from satpy.readers.utils import bbox, get_geostationary_angle_extent
 
 logger = logging.getLogger(__name__)
@@ -639,10 +638,9 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         """Determine whether the given channel is a visible channel."""
         if isinstance(channel, str):
             return channel == '00_7'
-        elif isinstance(channel, int):
+        if isinstance(channel, int):
             return channel == 1
-        else:
-            raise ValueError('Invalid channel')
+        raise ValueError('Invalid channel')
 
     @staticmethod
     def _get_earth_mask(lat):
@@ -728,8 +726,8 @@ class GOESNCBaseFileHandler(BaseFileHandler):
                 area_extent)
 
             return area_def
-        else:
-            return None
+
+        return None
 
     @property
     def start_time(self):
@@ -1040,8 +1038,8 @@ class GOESNCFileHandler(GOESNCBaseFileHandler):
         coefs = CALIB_COEFS[self.platform_name][channel]
         if calibration == 'counts':
             return counts
-        elif calibration in ['radiance', 'reflectance',
-                             'brightness_temperature']:
+        if calibration in ['radiance', 'reflectance',
+                           'brightness_temperature']:
             radiance = self._counts2radiance(counts=counts, coefs=coefs,
                                              channel=channel)
             if calibration == 'radiance':
@@ -1049,9 +1047,8 @@ class GOESNCFileHandler(GOESNCBaseFileHandler):
 
             return self._calibrate(radiance=radiance, coefs=coefs,
                                    channel=channel, calibration=calibration)
-        else:
-            raise ValueError('Unsupported calibration for channel {}: {}'
-                             .format(channel, calibration))
+
+        raise ValueError('Unsupported calibration for channel {}: {}'.format(channel, calibration))
 
 
 class GOESEUMNCFileHandler(GOESNCBaseFileHandler):
@@ -1099,14 +1096,14 @@ class GOESEUMNCFileHandler(GOESNCBaseFileHandler):
         # IR files provide radiances, VIS file provides reflectances
         if is_vis and calibration == 'reflectance':
             return data
-        elif not is_vis and calibration == 'radiance':
+        if not is_vis and calibration == 'radiance':
             return data
-        elif not is_vis and calibration == 'brightness_temperature':
+        if not is_vis and calibration == 'brightness_temperature':
             return self._calibrate(radiance=data, calibration=calibration,
                                    coefs=coefs, channel=channel)
-        else:
-            raise ValueError('Unsupported calibration for channel {}: {}'
-                             .format(channel, calibration))
+
+        raise ValueError('Unsupported calibration for channel {}: {}'
+                         .format(channel, calibration))
 
 
 class GOESEUMGEONCFileHandler(BaseFileHandler):
@@ -1212,8 +1209,7 @@ class GOESCoefficientReader(object):
             response = requests.get(url)
             if response.ok:
                 return response.text
-            else:
-                raise requests.HTTPError
+            raise requests.HTTPError
         except (MissingSchema, requests.HTTPError):
             # Not a valid URL, is it a file?
             try:
@@ -1298,7 +1294,7 @@ class GOESCoefficientReader(object):
         if not headings:
             raise ValueError('Cannot find a coefficient table matching text '
                              '"{}"'.format(heading))
-        elif len(headings) > 1:
+        if len(headings) > 1:
             raise ValueError('Found multiple headings matching text "{}"'
                              .format(heading))
         table = headings[0].next_sibling.next_sibling
