@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009-2016 Satpy developers
+# Copyright (c) 2009-2021 Satpy developers
 #
 # This file is part of satpy.
 #
@@ -32,13 +32,16 @@ http://www.ncdc.noaa.gov/oa/pod-guide/ncdc/docs/klm/html/c7/sec7-1.htm
 import logging
 from datetime import datetime
 
+import dask.array as da
 import numpy as np
-try:
-    from pygac.calibration import calibrate_solar, calibrate_thermal
-except ImportError:
-    from pygac.gac_calibration import calibrate_solar, calibrate_thermal
+import xarray as xr
+from geotiepoints import SatelliteInterpolator
+from pyorbital.geoloc import compute_pixels, get_lonlatalt
+from pyorbital.geoloc_instrument_definitions import avhrr
+from pyorbital.orbital import Orbital
 
-from satpy.dataset import Dataset
+from satpy._compat import cached_property
+from satpy.readers.aapp_l1b import LINE_CHUNK
 from satpy.readers.file_handlers import BaseFileHandler
 
 logger = logging.getLogger(__name__)
@@ -82,7 +85,7 @@ def time_seconds(tc_array, year):
 
 def bfield(array, bit):
     """Return the bit array."""
-    return (array & 2**(9 - bit + 1)).astype(np.bool)
+    return (array & 2**(9 - bit + 1)).astype(bool)
 
 
 spacecrafts = {7: "NOAA 15", 3: "NOAA 16", 13: "NOAA 18", 15: "NOAA 19"}
@@ -90,7 +93,6 @@ spacecrafts = {7: "NOAA 15", 3: "NOAA 16", 13: "NOAA 18", 15: "NOAA 19"}
 
 def geo_interpolate(lons32km, lats32km):
     """Interpolate geo data."""
-    from geotiepoints import SatelliteInterpolator
     cols32km = np.arange(0, 2048, 32)
     cols1km = np.arange(2048)
     lines = lons32km.shape[0]
@@ -107,6 +109,18 @@ def geo_interpolate(lons32km, lats32km):
     return lons, lats
 
 
+def _get_channel_index(key):
+    """Get the avhrr channel index."""
+    avhrr_channel_index = {'1': 0,
+                           '2': 1,
+                           '3a': 2,
+                           '3b': 2,
+                           '4': 3,
+                           '5': 4}
+    index = avhrr_channel_index[key['name']]
+    return index
+
+
 class HRPTFile(BaseFileHandler):
     """Reader for HRPT Minor Frame, 10 bits data expanded to 16 bits."""
 
@@ -116,135 +130,138 @@ class HRPTFile(BaseFileHandler):
         self.channels = {i: None for i in AVHRR_CHANNEL_NAMES}
         self.units = {i: 'counts' for i in AVHRR_CHANNEL_NAMES}
 
-        self._data = None
-        self._is3b = None
-        self.lons = None
-        self.lats = None
-        self.area = None
-        self.platform_name = None
         self.year = filename_info.get('start_time', datetime.utcnow()).year
-        self.times = None
-        self.prt = None
-        self.ict = None
-        self.space = None
-        self.read()
+
+    @cached_property
+    def times(self):
+        """Get the timestamps for each line."""
+        return time_seconds(self._data["timecode"], self.year)
+
+    @cached_property
+    def _data(self):
+        """Get the data."""
+        return self.read()
 
     def read(self):
         """Read the file."""
         with open(self.filename, "rb") as fp_:
-            self._data = np.memmap(fp_, dtype=dtype, mode="r")
-        if np.all(self._data['frame_sync'][0] > 1024):
-            self._data = self._data.newbyteorder()
-        self.platform_name = spacecrafts[
-            (self._data["id"]["id"][0] >> 3) & 15]
+            data = np.memmap(fp_, dtype=dtype, mode="r")
+        if np.all(np.median(data['frame_sync'], axis=0) > 1024):
+            data = self._data.newbyteorder()
+        return data
+
+    @cached_property
+    def platform_name(self):
+        """Get the platform name."""
+        return spacecrafts[np.median((self._data["id"]["id"] >> 3) & 15)]
 
     def get_dataset(self, key, info):
         """Get the dataset."""
-        if self._data is None:
-            self.read()
+        attrs = info.copy()
+        attrs['platform_name'] = self.platform_name
 
         if key['name'] in ['latitude', 'longitude']:
-            lons, lats = self.get_lonlats()
-            if key['name'] == 'latitude':
-                return Dataset(lats, id=key)
-            else:
-                return Dataset(lons, id=key)
+            data = self._get_navigation_data(key)
+        else:
+            data = self._get_channel_data(key)
 
-        avhrr_channel_index = {'1': 0,
-                               '2': 1,
-                               '3a': 2,
-                               '3b': 2,
-                               '4': 3,
-                               '5': 4}
-        index = avhrr_channel_index[key['name']]
-        mask = False
-        if key['name'] in ['3a', '3b'] and self._is3b is None:
-            ch3a = bfield(self._data["id"]["id"], 10)
-            self._is3b = np.logical_not(ch3a)
+        result = xr.DataArray(data, dims=['y', 'x'], attrs=attrs)
+        mask = self._get_ch3_mask_or_true(key)
+        return result.where(mask)
 
+    def _get_channel_data(self, key):
+        """Get channel data."""
+        data = da.from_array(self._data["image_data"][:, :, _get_channel_index(key)], chunks=(LINE_CHUNK, 2048))
+        if key['calibration'] != 'counts':
+            if key['name'] in ['1', '2', '3a']:
+                data = self.calibrate_solar_channel(data, key)
+
+            if key['name'] in ['3b', '4', '5']:
+                data = self.calibrate_thermal_channel(data, key)
+        return data
+
+    def _get_navigation_data(self, key):
+        """Get navigation data."""
+        lons, lats = self.lons_lats
+        if key['name'] == 'latitude':
+            data = da.from_array(lats, chunks=(LINE_CHUNK, 2048))
+        else:
+            data = da.from_array(lons, chunks=(LINE_CHUNK, 2048))
+        return data
+
+    def _get_ch3_mask_or_true(self, key):
+        mask = True
         if key['name'] == '3a':
-            mask = np.tile(self._is3b, (1, 2048))
+            mask = np.tile(np.logical_not(self._is3b), (2048, 1)).T
         elif key['name'] == '3b':
-            mask = np.tile(np.logical_not(self._is3b), (1, 2048))
+            mask = np.tile(self._is3b, (2048, 1)).T
+        return mask
 
-        data = self._data["image_data"][:, :, index]
-        if key['calibration'] == 'counts':
-            return Dataset(data,
-                           mask=mask,
-                           area=self.get_lonlats(),
-                           units='1')
+    @cached_property
+    def _is3b(self):
+        return bfield(self._data["id"]["id"], 10) == 0
 
+    def calibrate_thermal_channel(self, data, key):
+        """Calibrate a thermal channel."""
+        from pygac.calibration import calibrate_thermal
+        line_numbers = (
+            np.round((self.times - self.times[-1]) /
+                     np.timedelta64(166666667, 'ns'))).astype(int)
+        line_numbers -= line_numbers[0]
+        prt, ict, space = self.telemetry
+        index = _get_channel_index(key)
+        data = calibrate_thermal(data, prt, ict[:, index - 2],
+                                 space[:, index], line_numbers,
+                                 index + 1, self.calibrator)
+        return data
+
+    def calibrate_solar_channel(self, data, key):
+        """Calibrate a solar channel."""
+        from pygac.calibration import calibrate_solar
+        julian_days = ((np.datetime64(self.start_time)
+                        - np.datetime64(str(self.year) + '-01-01T00:00:00Z'))
+                       / np.timedelta64(1, 'D'))
+        data = calibrate_solar(data, _get_channel_index(key), self.year, julian_days,
+                               self.calibrator)
+        return data
+
+    @cached_property
+    def calibrator(self):
+        """Create a calibrator for the data."""
+        from pygac.calibration import Calibrator
         pg_spacecraft = ''.join(self.platform_name.split()).lower()
+        return Calibrator(pg_spacecraft)
 
-        jdays = (np.datetime64(self.start_time) - np.datetime64(str(
-            self.year) + '-01-01T00:00:00Z')) / np.timedelta64(1, 'D')
-        if index < 2 or key['name'] == '3a':
-            data = calibrate_solar(data, index, self.year, jdays,
-                                   pg_spacecraft)
-            units = '%'
-
-        if index > 2 or key['name'] == '3b':
-            if self.times is None:
-                self.times = time_seconds(self._data["timecode"], self.year)
-            line_numbers = (
-                np.round((self.times - self.times[-1]) /
-                         np.timedelta64(166666667, 'ns'))).astype(np.int)
-            line_numbers -= line_numbers[0]
-            if self.prt is None:
-                self.prt, self.ict, self.space = self.get_telemetry()
-            chan = index + 1
-            data = calibrate_thermal(data, self.prt, self.ict[:, chan - 3],
-                                     self.space[:, chan - 3], line_numbers,
-                                     chan, pg_spacecraft)
-            units = 'K'
-        # TODO: check if entirely masked before returning
-        return Dataset(data, mask=mask, units=units)
-
-    def get_telemetry(self):
+    @cached_property
+    def telemetry(self):
         """Get the telemetry."""
+        # This isn't converted to dask arrays as it does not work with pygac
         prt = np.mean(self._data["telemetry"]['PRT'], axis=1)
-
-        ict = np.empty((len(self._data), 3))
-        for i in range(3):
-            ict[:, i] = np.mean(self._data['back_scan'][:, :, i], axis=1)
-
-        space = np.empty((len(self._data), 3))
-        for i in range(3):
-            space[:, i] = np.mean(self._data['space_data'][
-                                  :, :, i + 2], axis=1)
+        ict = np.mean(self._data['back_scan'], axis=1)
+        space = np.mean(self._data['space_data'][:, :], axis=1)
 
         return prt, ict, space
 
-    def get_lonlats(self):
-        """Get the lonlats."""
-        if self.lons is not None and self.lats is not None:
-            return self.lons, self.lats
-        from pyorbital.orbital import Orbital
-        from pyorbital.geoloc import compute_pixels, get_lonlatalt
-        from pyorbital.geoloc_instrument_definitions import avhrr
-
-        if self.times is None:
-            self.times = time_seconds(self._data["timecode"], self.year)
+    @cached_property
+    def lons_lats(self):
+        """Get the lons and lats."""
         scanline_nb = len(self.times)
         scan_points = np.arange(0, 2048, 32)
-        # scan_points = np.arange(2048)
+        lons, lats = self._get_avhrr_tiepoints(scan_points, scanline_nb)
 
+        lons, lats = geo_interpolate(
+            lons.reshape((scanline_nb, -1)), lats.reshape((scanline_nb, -1)))
+        return lons, lats
+
+    def _get_avhrr_tiepoints(self, scan_points, scanline_nb):
         sgeom = avhrr(scanline_nb, scan_points, apply_offset=False)
         # no attitude error
         rpy = [0, 0, 0]
-        s_times = sgeom.times(
-            self.times[:, np.newaxis]).ravel()
-        # s_times = (np.tile(sgeom._times[0, :], (scanline_nb, 1)).astype(
-        #    'timedelta64[s]') + self.times[:, np.newaxis]).ravel()
-
+        s_times = sgeom.times(self.times[:, np.newaxis])
         orb = Orbital(self.platform_name)
-
         pixels_pos = compute_pixels(orb, sgeom, s_times, rpy)
         lons, lats, alts = get_lonlatalt(pixels_pos, s_times)
-        self.lons, self.lats = geo_interpolate(
-            lons.reshape((scanline_nb, -1)), lats.reshape((scanline_nb, -1)))
-
-        return self.lons, self.lats
+        return lons, lats
 
     @property
     def start_time(self):
