@@ -49,6 +49,7 @@ from satpy.readers.seviri_base import (
     OrbitPolynomialFinder,
     SEVIRICalibrationHandler,
     add_scanline_acq_time,
+    calculate_area_extent,
     create_coef_dict,
     dec10216,
     get_cds_time,
@@ -136,19 +137,6 @@ class NativeMSGFileHandler(BaseFileHandler):
         return self.header['15_DATA_HEADER']['ImageAcquisition'][
             'PlannedAcquisitionTime']['PlannedRepeatCycleEnd']
 
-    @staticmethod
-    def _calculate_area_extent(center_point, north, east, south, west,
-                               we_offset, ns_offset, column_step, line_step):
-        # For Earth model 2 and full disk VISIR, (center_point - west - 0.5 + we_offset) must be -1856.5 .
-        # See MSG Level 1.5 Image Data Format Description Figure 7 - Alignment and numbering of the non-HRV pixels.
-
-        ll_c = (center_point - east + 0.5 + we_offset) * column_step
-        ll_l = (north - center_point + 0.5 + ns_offset) * line_step
-        ur_c = (center_point - west - 0.5 + we_offset) * column_step
-        ur_l = (south - center_point - 0.5 + ns_offset) * line_step
-
-        return (ll_c, ll_l, ur_c, ur_l)
-
     def _get_data_dtype(self):
         """Get the dtype of the file based on the actual available channels."""
         pkhrec = [
@@ -421,8 +409,19 @@ class NativeMSGFileHandler(BaseFileHandler):
 
             nlines = north_bound - south_bound + 1
             ncolumns = west_bound - east_bound + 1
-            aex = self._calculate_area_extent(center_point, north_bound, east_bound, south_bound, west_bound,
-                                              we_offset, ns_offset, column_step, line_step)
+
+            area_dict = {'center_point': center_point,
+                         'east': east_bound,
+                         'west': west_bound,
+                         'south': south_bound,
+                         'north': north_bound,
+                         'column_step': column_step,
+                         'line_step': line_step,
+                         'column_offset': we_offset,
+                         'line_offset': ns_offset
+                         }
+
+            aex = calculate_area_extent(area_dict)
 
             aex_data['area_extent'].append(aex)
             aex_data['nlines'].append(nlines)
