@@ -21,11 +21,10 @@
 References:
     FM 92 GRIB Edition 2
     https://www.wmo.int/pages/prog/www/WMOCodes/Guides/GRIB/GRIB2_062006.pdf
-
     EUMETSAT Product Navigator
     https://navigator.eumetsat.int/
-
 """
+
 import logging
 from datetime import timedelta
 
@@ -34,7 +33,8 @@ import numpy as np
 import xarray as xr
 
 from satpy import CHUNK_SIZE
-from satpy.readers._geos_area import get_area_definition
+from satpy.readers._geos_area import get_area_definition, get_geos_area_naming
+from satpy.readers.eum_base import get_service_mode
 from satpy.readers.file_handlers import BaseFileHandler
 from satpy.readers.seviri_base import PLATFORM_DICT, REPEAT_CYCLE_DURATION, calculate_area_extent
 
@@ -44,7 +44,6 @@ except ImportError:
     raise ImportError(
         "Missing eccodes-python and/or eccodes C-library installation. Use conda to install eccodes")
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -56,48 +55,6 @@ class SeviriL2GribFileHandler(BaseFileHandler):
         super().__init__(filename, filename_info, filetype_info)
         # Turn on support for multiple fields in single GRIB messages (required for SEVIRI L2 files)
         ec.codes_grib_multi_support_on()
-        self._read_global_attributes()
-
-    def _read_global_attributes(self):
-        """Read the global product attributes from the first message.
-
-        Read the information about the date and time of the data product,
-        the projection and area definition and the number of messages.
-
-        """
-        with open(self.filename, 'rb') as fh:
-            gid = ec.codes_grib_new_from_file(fh)
-
-            if gid is None:
-                # Could not obtain a valid message id: set attributes to None, number of messages to 0
-                logger.warning("Could not obtain a valid message id in GRIB file")
-
-                self._ssp_lon = None
-                self._nrows = None
-                self._ncols = None
-                self._pdict, self._area_dict = None, None
-
-                return
-
-            # Read SSP and date/time
-            self._ssp_lon = self._get_from_msg(gid, 'longitudeOfSubSatellitePointInDegrees')
-
-            # Read number of points on the x and y axes
-            self._nrows = self._get_from_msg(gid, 'Ny')
-            self._ncols = self._get_from_msg(gid, 'Nx')
-
-            # Creates the projection and area dictionaries
-            self._pdict, self._area_dict = self._get_proj_area(gid)
-
-            # Determine the number of messages in the product by iterating until an invalid id is obtained
-            i = 1
-            ec.codes_release(gid)
-            while True:
-                gid = ec.codes_grib_new_from_file(fh)
-                if gid is None:
-                    break
-                ec.codes_release(gid)
-                i = i+1
 
     @property
     def start_time(self):
@@ -111,10 +68,10 @@ class SeviriL2GribFileHandler(BaseFileHandler):
 
     def get_area_def(self, dataset_id):
         """Return the area definition for a dataset."""
-        # The area extension depends on the resolution of the dataset
-        area_dict = self._area_dict.copy()
-        area_dict['resolution'] = dataset_id.resolution
-        area_extent = calculate_area_extent(area_dict)
+        self._area_dict['column_step'] = dataset_id.resolution
+        self._area_dict['line_step'] = dataset_id.resolution
+
+        area_extent = calculate_area_extent(self._area_dict)
 
         # Call the get_area_definition function to obtain the area
         area_def = get_area_definition(self._pdict, area_extent)
@@ -122,54 +79,80 @@ class SeviriL2GribFileHandler(BaseFileHandler):
         return area_def
 
     def get_dataset(self, dataset_id, dataset_info):
-        """Get dataset using the parameter_number key in dataset_info."""
+        """Get dataset using the parameter_number key in dataset_info.
+
+        In a previous version of the reader, the attributes (nrows, ncols, ssp_lon) and projection information
+        (pdict and area_dict) were computed while initializing the file handler. Also the code would break out from
+        the While-loop below as soon as the correct parameter_number was found. This has now been revised becasue the
+        reader would sometimes give corrupt information about the number of messages in the file and the dataset
+        dimensions within a given message if the file was only partly read (not looping over all messages) in an earlier
+        instance.
+        """
         logger.debug('Reading in file to get dataset with parameter number %d.',
                      dataset_info['parameter_number'])
 
         xarr = None
-
+        message_found = False
         with open(self.filename, 'rb') as fh:
-            # Iterate until a message containing the correct parameter number is found
+
+            # Iterate over all messages and fetch data when the correct parameter number is found
             while True:
                 gid = ec.codes_grib_new_from_file(fh)
 
                 if gid is None:
-                    # Could not obtain a valid message ID, break out of the loop
-                    logger.warning("Could not find parameter_number %d in GRIB file, no valid Dataset created",
-                                   dataset_info['parameter_number'])
+                    if not message_found:
+                        # Could not obtain a valid message ID from the grib file
+                        logger.warning("Could not find parameter_number %d in GRIB file, no valid Dataset created",
+                                       dataset_info['parameter_number'])
                     break
 
                 # Check if the parameter number in the GRIB message corresponds to the required key
                 parameter_number = self._get_from_msg(gid, 'parameterNumber')
 
-                if parameter_number != dataset_info['parameter_number']:
-                    # The parameter number is not the correct one, skip to next message
+                if parameter_number == dataset_info['parameter_number']:
+
+                    self._res = dataset_id.resolution
+                    self._read_attributes(gid)
+
+                    # Read the missing value
+                    missing_value = self._get_from_msg(gid, 'missingValue')
+
+                    # Retrieve values and metadata from the GRIB message, masking the values equal to missing_value
+                    xarr = self._get_xarray_from_msg(gid)
+
+                    xarr.data = da.where(xarr.data == missing_value, np.nan, xarr.data)
+
                     ec.codes_release(gid)
-                    continue
 
-                # Read the missing value
-                missing_value = self._get_from_msg(gid, 'missingValue')
+                    # Combine all metadata into the dataset attributes and break out of the loop
+                    xarr.attrs.update(dataset_info)
+                    xarr.attrs.update(self._get_attributes())
 
-                # Retrieve values and metadata from the GRIB message, masking the values equal to missing_value
-                xarr = self._get_xarray_from_msg(gid)
+                    message_found = True
 
-                xarr.data = da.where(xarr.data == missing_value, np.nan, xarr.data)
-
-                ec.codes_release(gid)
-
-                # Combine all metadata into the dataset attributes and break out of the loop
-                xarr.attrs.update(dataset_info)
-                xarr.attrs.update(self._get_global_attributes())
-                break
+                else:
+                    # The parameter number is not the correct one, release gid and skip to next message
+                    ec.codes_release(gid)
 
         return xarr
 
+    def _read_attributes(self, gid):
+        """Read the parameter attributes from the message and create the projection and area dictionaries."""
+        # Read SSP and date/time
+        self._ssp_lon = self._get_from_msg(gid, 'longitudeOfSubSatellitePointInDegrees')
+
+        # Read number of points on the x and y axes
+        self._nrows = self._get_from_msg(gid, 'Ny')
+        self._ncols = self._get_from_msg(gid, 'Nx')
+
+        # Creates the projection and area dictionaries
+        self._pdict, self._area_dict = self._get_proj_area(gid)
+
     def _get_proj_area(self, gid):
         """Compute the dictionary with the projection and area definition from a GRIB message.
 
         Args:
             gid: The ID of the GRIB message.
-
         Returns:
             tuple: A tuple of two dictionaries for the projection and the area definition.
                 pdict:
@@ -188,14 +171,26 @@ class SeviriL2GribFileHandler(BaseFileHandler):
                     east: coodinate of the east limit
                     west: coodinate of the west limit
                     south: coodinate of the south limit
-
         """
+        # Get name of area definition
+        area_naming_input_dict = {'platform_name': 'msg',
+                                  'instrument_name': 'seviri',
+                                  'resolution': self._res,
+                                  }
+
+        area_naming = get_geos_area_naming({**area_naming_input_dict,
+                                            **get_service_mode('seviri', self._ssp_lon)})
+
         # Read all projection and area parameters from the message
-        earth_major_axis_in_meters = self._get_from_msg(gid, 'earthMajorAxis') * 1000.0   # [m]
-        earth_minor_axis_in_meters = self._get_from_msg(gid, 'earthMinorAxis') * 1000.0   # [m]
+        earth_major_axis_in_meters = self._get_from_msg(gid, 'earthMajorAxis') * 1000.0  # [m]
+        earth_minor_axis_in_meters = self._get_from_msg(gid, 'earthMinorAxis') * 1000.0  # [m]
+
+        earth_major_axis_in_meters = self._scale_earth_axis(earth_major_axis_in_meters)
+        earth_minor_axis_in_meters = self._scale_earth_axis(earth_minor_axis_in_meters)
+
         nr_in_radius_of_earth = self._get_from_msg(gid, 'NrInRadiusOfEarth')
         xp_in_grid_lengths = self._get_from_msg(gid, 'XpInGridLengths')
-        h_in_meters = earth_major_axis_in_meters * (nr_in_radius_of_earth - 1.0)   # [m]
+        h_in_meters = earth_major_axis_in_meters * (nr_in_radius_of_earth - 1.0)  # [m]
 
         # Create the dictionary with the projection data
         pdict = {
@@ -205,14 +200,14 @@ class SeviriL2GribFileHandler(BaseFileHandler):
             'ssp_lon': self._ssp_lon,
             'nlines': self._ncols,
             'ncols': self._nrows,
-            'a_name': 'geos_seviri',
-            'a_desc': 'Calculated area for SEVIRI L2 GRIB product',
-            'p_id': 'geos',
+            'a_name': area_naming['area_id'],
+            'a_desc': area_naming['description'],
+            'p_id': "",
         }
 
         # Compute the dictionary with the area extension
         area_dict = {
-            'center_point': xp_in_grid_lengths + 0.5,
+            'center_point': xp_in_grid_lengths,
             'north': self._nrows,
             'east': 1,
             'west': self._ncols,
@@ -221,15 +216,26 @@ class SeviriL2GribFileHandler(BaseFileHandler):
 
         return pdict, area_dict
 
+    @staticmethod
+    def _scale_earth_axis(data):
+        """Scale Earth axis data to make sure the value matched the expected unit [m].
+
+        The earthMinorAxis value stored in the aerosol over sea product is scaled incorrectly by a factor of 1e8. This
+        method provides a flexible temporarily workaraound by making sure that all earth axis values are scaled such
+        that they are on the order of millions of meters as expected by the reader. As soon as the scaling issue has
+        been resolved by EUMETSAT this workaround can be removed.
+
+        """
+        scale_factor = 10 ** np.ceil(np.log10(1e6/data))
+        return data * scale_factor
+
     def _get_xarray_from_msg(self, gid):
         """Read the values from the GRIB message and return a DataArray object.
 
         Args:
             gid: The ID of the GRIB message.
-
         Returns:
             DataArray: The array containing the retrieved values.
-
         """
         # Data from GRIB message are read into an Xarray...
         xarr = xr.DataArray(da.from_array(ec.codes_get_values(
@@ -237,15 +243,14 @@ class SeviriL2GribFileHandler(BaseFileHandler):
 
         return xarr
 
-    def _get_global_attributes(self):
-        """Create a dictionary of global attributes to be added to all datasets.
+    def _get_attributes(self):
+        """Create a dictionary of  attributes to be added to the dataset.
 
         Returns:
-            dict: A dictionary of global attributes.
+            dict: A dictionary of parameter attributes.
                 ssp_lon: longitude of subsatellite point
                 sensor: name of sensor
                 platform_name: name of the platform
-
         """
         orbital_parameters = {
             'projection_longitude': self._ssp_lon
@@ -258,16 +263,15 @@ class SeviriL2GribFileHandler(BaseFileHandler):
         }
         return attributes
 
-    def _get_from_msg(self, gid, key):
+    @staticmethod
+    def _get_from_msg(gid, key):
         """Get a value from the GRIB message based on the key, return None if missing.
 
         Args:
             gid: The ID of the GRIB message.
             key: The key of the required attribute.
-
         Returns:
             The retrieved attribute or None if the key is missing.
-
         """
         try:
             attr = ec.codes_get(gid, key)
