@@ -137,6 +137,7 @@ class TestVIIRSComposites(unittest.TestCase):
                       standard_name='toa_outgoing_radiance_per_'
                                     'unit_wavelength')
         dnb = np.zeros((rows, cols)) + 0.25
+        dnb[2, :cols // 2] = np.nan
         dnb[3, :] += 0.25
         dnb[4:, :] += 0.5
         dnb = da.from_array(dnb, chunks=25)
@@ -168,8 +169,12 @@ class TestVIIRSComposites(unittest.TestCase):
                          'equalized_radiance')
         data = res.compute()
         unique = np.unique(data)
-        np.testing.assert_allclose(unique, [0.00000000e+00, 1.00446703e-01, 1.64116082e-01, 2.09233451e-01,
-                                            1.43916324e+02, 2.03528498e+02, 2.49270516e+02])
+        assert np.isnan(unique).any()
+        nonnan_unique = unique[~np.isnan(unique)]
+        np.testing.assert_allclose(
+            nonnan_unique,
+            [0.00000000e+00, 1.00446703e-01, 1.64116082e-01, 2.09233451e-01,
+             1.43916324e+02, 2.03528498e+02, 2.49270516e+02])
 
     def test_hncc_dnb(self):
         """Test the 'hncc_dnb' compositor."""
