@@ -13,16 +13,18 @@
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 # A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 """Tests for the CREFL ReflectanceCorrector modifier."""
-from unittest import mock
 from contextlib import contextmanager
 from datetime import datetime
+from unittest import mock
 
 import numpy as np
 import pytest
-from dask import array as da
 import xarray as xr
+from dask import array as da
 from pyresample.geometry import AreaDefinition
 
+from ..utils import assert_maximum_dask_computes
+
 
 @contextmanager
 def mock_cmgdem(tmpdir, url):
@@ -100,7 +102,7 @@ class TestReflectanceCorrectorModifier:
         data = np.zeros((rows, cols)) + 25
         data[3, :] += 25
         data[4:, :] += 50
-        data = da.from_array(data, chunks=100)
+        data = da.from_array(data, chunks=2)
         return area, data
 
     def test_reflectance_corrector_abi(self):
@@ -139,7 +141,8 @@ class TestReflectanceCorrectorModifier:
                                'start_time': '2017-09-20 17:30:40.800000', 'end_time': '2017-09-20 17:41:17.500000',
                                'area': area, 'ancillary_variables': []
                            })
-        res = ref_cor([c01], [])
+        with assert_maximum_dask_computes(0):
+            res = ref_cor([c01], [])
 
         assert isinstance(res, xr.DataArray)
         assert isinstance(res.data, da.Array)
@@ -227,7 +230,7 @@ class TestReflectanceCorrectorModifier:
         c04 = _make_viirs_xarray(data, area, 'solar_azimuth_angle', 'solar_azimuth_angle')
         c05 = _make_viirs_xarray(data, area, 'solar_zenith_angle', 'solar_zenith_angle')
 
-        with dem_mock_cm(tmpdir, url):
+        with dem_mock_cm(tmpdir, url), assert_maximum_dask_computes(0):
             res = ref_cor([c01], [c02, c03, c04, c05])
 
         assert isinstance(res, xr.DataArray)
