@@ -34,7 +34,7 @@ AVAILABLE_1KM_IR_PRODUCT_NAMES = [str(x) for x in range(20, 37)]
 AVAILABLE_1KM_PRODUCT_NAMES = AVAILABLE_1KM_VIS_PRODUCT_NAMES + AVAILABLE_1KM_IR_PRODUCT_NAMES
 AVAILABLE_HKM_PRODUCT_NAMES = [str(x) for x in range(3, 8)]
 AVAILABLE_QKM_PRODUCT_NAMES = ['1', '2']
-SCAN_LEN_5KM = 406
+SCAN_LEN_5KM = 6  # 3 scans of 5km data
 SCAN_WIDTH_5KM = 270
 SCALE_FACTOR = 1
 RES_TO_REPEAT_FACTOR = {
