@@ -42,7 +42,7 @@ class TestGenericImage(unittest.TestCase):
 
         # Create area definition
         pcs_id = 'ETRS89 / LAEA Europe'
-        proj4_dict = {'init': 'epsg:3035'}
+        proj4_dict = "EPSG:3035"
         self.x_size = 100
         self.y_size = 100
         area_extent = (2426378.0132, 1528101.2618, 6293974.6215, 5446513.5222)
