@@ -204,8 +204,7 @@ class GOESNCBaseFileHandlerTest(unittest.TestCase):
 
     def test_end_time(self):
         """Test dataset end time stamp."""
-        from satpy.readers.goes_imager_nc import (SCAN_DURATION, FULL_DISC,
-                                                  UNKNOWN_SECTOR)
+        from satpy.readers.goes_imager_nc import FULL_DISC, SCAN_DURATION, UNKNOWN_SECTOR
         expected = {
             UNKNOWN_SECTOR: self.time,
             FULL_DISC: self.time + SCAN_DURATION[FULL_DISC]
@@ -223,7 +222,7 @@ class GOESNCFileHandlerTest(unittest.TestCase):
     @mock.patch('satpy.readers.goes_imager_nc.xr')
     def setUp(self, xr_):
         """Set up the tests."""
-        from satpy.readers.goes_imager_nc import GOESNCFileHandler, CALIB_COEFS
+        from satpy.readers.goes_imager_nc import CALIB_COEFS, GOESNCFileHandler
 
         self.coefs = CALIB_COEFS['GOES-15']
         self.all_coefs = CALIB_COEFS
@@ -359,9 +358,14 @@ class GOESNCFileHandlerTest(unittest.TestCase):
 
     def test_get_sector(self):
         """Test sector identification."""
-        from satpy.readers.goes_imager_nc import (FULL_DISC, NORTH_HEMIS_EAST,
-                                                  SOUTH_HEMIS_EAST, NORTH_HEMIS_WEST,
-                                                  SOUTH_HEMIS_WEST, UNKNOWN_SECTOR)
+        from satpy.readers.goes_imager_nc import (
+            FULL_DISC,
+            NORTH_HEMIS_EAST,
+            NORTH_HEMIS_WEST,
+            SOUTH_HEMIS_EAST,
+            SOUTH_HEMIS_WEST,
+            UNKNOWN_SECTOR,
+        )
         shapes_vis = {
             (10800, 20754): FULL_DISC,
             (7286, 13900): NORTH_HEMIS_EAST,
@@ -399,7 +403,7 @@ class GOESNCEUMFileHandlerRadianceTest(unittest.TestCase):
     @mock.patch('satpy.readers.goes_imager_nc.xr')
     def setUp(self, xr_):
         """Set up the tests."""
-        from satpy.readers.goes_imager_nc import GOESEUMNCFileHandler, CALIB_COEFS
+        from satpy.readers.goes_imager_nc import CALIB_COEFS, GOESEUMNCFileHandler
 
         self.coefs = CALIB_COEFS['GOES-15']
         self.all_coefs = CALIB_COEFS
@@ -456,9 +460,14 @@ class GOESNCEUMFileHandlerRadianceTest(unittest.TestCase):
 
     def test_get_sector(self):
         """Test sector identification."""
-        from satpy.readers.goes_imager_nc import (FULL_DISC, NORTH_HEMIS_EAST,
-                                                  SOUTH_HEMIS_EAST, NORTH_HEMIS_WEST,
-                                                  SOUTH_HEMIS_WEST, UNKNOWN_SECTOR)
+        from satpy.readers.goes_imager_nc import (
+            FULL_DISC,
+            NORTH_HEMIS_EAST,
+            NORTH_HEMIS_WEST,
+            SOUTH_HEMIS_EAST,
+            SOUTH_HEMIS_WEST,
+            UNKNOWN_SECTOR,
+        )
         shapes = {
             (2700, 5200): FULL_DISC,
             (1850, 3450): NORTH_HEMIS_EAST,
@@ -483,7 +492,7 @@ class GOESNCEUMFileHandlerReflectanceTest(unittest.TestCase):
     @mock.patch('satpy.readers.goes_imager_nc.xr')
     def setUp(self, xr_):
         """Set up the tests."""
-        from satpy.readers.goes_imager_nc import GOESEUMNCFileHandler, CALIB_COEFS
+        from satpy.readers.goes_imager_nc import CALIB_COEFS, GOESEUMNCFileHandler
 
         self.coefs = CALIB_COEFS['GOES-15']
         self.all_coefs = CALIB_COEFS
