@@ -17,6 +17,8 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Unit tests for the FIDUCEO MVIRI FCDR Reader."""
 
+from __future__ import annotations
+
 import os
 from unittest import mock
 
@@ -28,12 +30,16 @@ from pyresample.geometry import AreaDefinition
 from pyresample.utils import proj4_radius_parameters
 
 from satpy.readers.mviri_l1b_fiduceo_nc import (
-    ALTITUDE, EQUATOR_RADIUS, POLE_RADIUS, FiduceoMviriEasyFcdrFileHandler,
-    FiduceoMviriFullFcdrFileHandler, DatasetWrapper
+    ALTITUDE,
+    EQUATOR_RADIUS,
+    POLE_RADIUS,
+    DatasetWrapper,
+    FiduceoMviriEasyFcdrFileHandler,
+    FiduceoMviriFullFcdrFileHandler,
 )
 from satpy.tests.utils import make_dataid
 
-attrs_exp = {
+attrs_exp: dict = {
     'platform': 'MET7',
     'raw_metadata': {'foo': 'bar'},
     'sensor': 'MVIRI',
