@@ -21,8 +21,10 @@ import unittest
 from unittest import mock
 
 import numpy as np
+import pytest
 
 from satpy.readers.file_handlers import BaseFileHandler
+from satpy.tests.utils import FakeFileHandler
 
 
 class TestBaseFileHandler(unittest.TestCase):
@@ -155,3 +157,20 @@ class TestBaseFileHandler(unittest.TestCase):
     def tearDown(self):
         """Tear down the test."""
         BaseFileHandler.__abstractmethods__ = self._old_set
+
+
+@pytest.mark.parametrize(
+    ("file_type", "ds_file_type", "exp_result"),
+    [
+        ("fake1", "fake1", True),
+        ("fake1", ["fake1"], True),
+        ("fake1", ["fake1", "fake2"], True),
+        ("fake1", ["fake2"], None),
+        ("fake1", "fake2", None),
+        ("fake1", "fake1_with_suffix", None),
+    ]
+)
+def test_file_type_match(file_type, ds_file_type, exp_result):
+    """Test that file type matching uses exactly equality."""
+    fh = FakeFileHandler("some_file.txt", {}, {"file_type": file_type})
+    assert fh.file_type_matches(ds_file_type) is exp_result
