@@ -168,3 +168,13 @@ class TestGeoTIFFWriter(unittest.TestCase):
             w.save_datasets(datasets, tags={'test2': 2}, compute=False, include_scale_offset=True)
             called_include = save_method.call_args[1]['include_scale_offset_tags']
             self.assertTrue(called_include)
+
+    def test_tiled_value_from_config(self):
+        """Test tiled value coming from the writer config."""
+        from satpy.writers.geotiff import GeoTIFFWriter
+        datasets = self._get_test_datasets()
+        w = GeoTIFFWriter(base_dir=self.base_dir)
+        with mock.patch('satpy.writers.XRImage.save') as save_method:
+            save_method.return_value = None
+            w.save_datasets(datasets, compute=False)
+            self.assertEqual(save_method.call_args[1]['tiled'], True)
